# stack-utils-node-internals [![NPM version](https://img.shields.io/npm/v/stack-utils-node-internals.svg?style=flat)](https://www.npmjs.com/package/stack-utils-node-internals) [![mit license][license-img]][license-url] [![NPM monthly downloads](https://img.shields.io/npm/dm/stack-utils-node-internals.svg?style=flat)](https://npmjs.org/package/stack-utils-node-internals) [![npm total downloads][downloads-img]][downloads-url]

> An array of node internals that can be cleaned up from stack traces

[![code climate][codeclimate-img]][codeclimate-url] 
[![code style][standard-img]][standard-url] 
[![linux build][travis-img]][travis-url] 
[![windows build][appveyor-img]][appveyor-url] 
[![code coverage][coverage-img]][coverage-url] 
[![dependency status][david-img]][david-url]
[![paypal donate][paypalme-img]][paypalme-url] 

You might also be interested in [stack-utils](https://github.com/tapjs/stack-utils#readme).

## Table of Contents
- [Install](#install)
- [Usage](#usage)
- [Related](#related)
- [Contributing](#contributing)
- [Building docs](#building-docs)
- [Running tests](#running-tests)
- [Author](#author)
- [License](#license)

_(TOC generated by [verb](https://github.com/verbose/verb) using [markdown-toc](https://github.com/jonschlinkert/markdown-toc))_

## Install
Install with [npm](https://www.npmjs.com/)

```
$ npm install stack-utils-node-internals --save
```

or install using [yarn](https://yarnpkg.com)

```
$ yarn add stack-utils-node-internals
```

## Usage
> For more use-cases see the [tests](test.js)

```js
const stackUtilsNodeInternals = require('stack-utils-node-internals')

const regexps = stackUtilsNodeInternals()
console.log(regexps)

const natives = stackUtilsNodeInternals.natives
console.log(natives)
// => [ 'internal/bootstrap_node',
//  '_debug_agent',
//  '_debugger',
//  'assert',
//  'buffer',
//  'child_process',
//  'console',
//  'constants',
//  'crypto',
//  'cluster',
//  'dgram',
//  'dns',
//  'domain',
//  'events',
//  'fs',
//  'http',
//  '_http_agent',
//  '_http_client',
//  '_http_common',
//  '_http_incoming',
//  '_http_outgoing',
//  '_http_server',
//  'https',
//  '_linklist',
//  'module',
//  'net',
//  'os',
//  'path',
//  'process',
//  'punycode',
//  'querystring',
//  'readline',
//  'repl',
//  'stream',
//  '_stream_readable',
//  '_stream_writable',
//  '_stream_duplex',
//  '_stream_transform',
//  '_stream_passthrough',
//  '_stream_wrap',
//  'string_decoder',
//  'sys',
//  'timers',
//  'tls',
//  '_tls_common',
//  '_tls_legacy',
//  '_tls_wrap',
//  'tty',
//  'url',
//  'util',
//  'v8',
//  'vm',
//  'zlib',
//  'internal/buffer',
//  'internal/child_process',
//  'internal/cluster/child',
//  'internal/cluster/master',
//  'internal/cluster/round_robin_handle',
//  'internal/cluster/shared_handle',
//  'internal/cluster/utils',
//  'internal/cluster/worker',
//  'internal/errors',
//  'internal/freelist',
//  'internal/fs',
//  'internal/linkedlist',
//  'internal/net',
//  'internal/module',
//  'internal/process/next_tick',
//  'internal/process/promises',
//  'internal/process/stdio',
//  'internal/process/warning',
//  'internal/process',
//  'internal/querystring',
//  'internal/process/write-coverage',
//  'internal/readline',
//  'internal/repl',
//  'internal/socket_list',
//  'internal/url',
//  'internal/util',
//  'internal/v8_prof_polyfill',
//  'internal/v8_prof_processor',
//  'internal/streams/lazy_transform',
//  'internal/streams/BufferList',
//  'internal/streams/legacy',
//  'v8/tools/splaytree',
//  'v8/tools/codemap',
//  'v8/tools/consarray',
//  'v8/tools/csvparser',
//  'v8/tools/profile',
//  'v8/tools/profile_view',
//  'v8/tools/logreader',
//  'v8/tools/tickprocessor',
//  'v8/tools/SourceMap',
//  'v8/tools/tickprocessor-driver',
//  'node-inspect/lib/_inspect',
//  'node-inspect/lib/internal/inspect_client',
//  'node-inspect/lib/internal/inspect_repl',
//  'bootstrap_node',
//  'node' ]
```

## Related
- [always-done](https://www.npmjs.com/package/always-done): Handle completion and errors with elegance! Support for streams, callbacks, promises, child processes, async/await and sync functions. A drop-in replacement… [more](https://github.com/hybridables/always-done#readme) | [homepage](https://github.com/hybridables/always-done#readme "Handle completion and errors with elegance! Support for streams, callbacks, promises, child processes, async/await and sync functions. A drop-in replacement for [async-done][] - pass 100% of its tests plus more")
- [clean-stack](https://www.npmjs.com/package/clean-stack): Clean up error stack traces | [homepage](https://github.com/sindresorhus/clean-stack#readme "Clean up error stack traces")
- [clean-stacktrace](https://www.npmjs.com/package/clean-stacktrace): Clean up error stack traces - just a fork of [clean-stack][]. Working on node.js v0.10 and above. | [homepage](https://github.com/tunnckocore/clean-stacktrace#readme "Clean up error stack traces - just a fork of [clean-stack][]. Working on node.js v0.10 and above.")
- [minibase](https://www.npmjs.com/package/minibase): Minimalist alternative for Base. Build complex APIs with small units called plugins. Works well with most of the already existing… [more](https://github.com/node-minibase/minibase#readme) | [homepage](https://github.com/node-minibase/minibase#readme "Minimalist alternative for Base. Build complex APIs with small units called plugins. Works well with most of the already existing [base][] plugins.")
- [stack-utils](https://www.npmjs.com/package/stack-utils): Captures and cleans stack traces | [homepage](https://github.com/tapjs/stack-utils#readme "Captures and cleans stack traces")
- [try-catch-core](https://www.npmjs.com/package/try-catch-core): Low-level package to handle completion and errors of sync or asynchronous functions, using [once][] and [dezalgo][] libs. Useful for and… [more](https://github.com/hybridables/try-catch-core#readme) | [homepage](https://github.com/hybridables/try-catch-core#readme "Low-level package to handle completion and errors of sync or asynchronous functions, using [once][] and [dezalgo][] libs. Useful for and used in higher-level libs such as [always-done][] to handle completion of anything.")

## Contributing
Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/tunnckoCore/stack-utils-node-internals/issues/new).  
Please read the [contributing guidelines](CONTRIBUTING.md) for advice on opening issues, pull requests, and coding standards.  
If you need some help and can spent some cash, feel free to [contact me at CodeMentor.io](https://www.codementor.io/tunnckocore?utm_source=github&utm_medium=button&utm_term=tunnckocore&utm_campaign=github) too.

**In short:** If you want to contribute to that project, please follow these things

1. Please DO NOT edit [README.md](README.md), [CHANGELOG.md](CHANGELOG.md) and [.verb.md](.verb.md) files. See ["Building docs"](#building-docs) section.
2. Ensure anything is okey by installing the dependencies and run the tests. See ["Running tests"](#running-tests) section.
3. Always use `npm run commit` to commit changes instead of `git commit`, because it is interactive and user-friendly. It uses [commitizen][] behind the scenes, which follows Conventional Changelog idealogy.
4. Do NOT bump the version in package.json. For that we use `npm run release`, which is [standard-version][] and follows Conventional Changelog idealogy.

Thanks a lot! :)

## Building docs
Documentation and that readme is generated using [verb-generate-readme][], which is a [verb][] generator, so you need to install both of them and then run `verb` command like that

```
$ npm install verbose/verb#dev verb-generate-readme --global && verb
```

_Please don't edit the README directly. Any changes to the readme must be made in [.verb.md](.verb.md)._

## Running tests
Clone repository and run the following in that cloned directory

```
$ npm install && npm test
```

## Author
**Charlike Mike Reagent**

+ [github/tunnckoCore](https://github.com/tunnckoCore)
+ [twitter/tunnckoCore](https://twitter.com/tunnckoCore)
+ [codementor/tunnckoCore](https://codementor.io/tunnckoCore)

## License
Copyright © 2016-2017, [Charlike Mike Reagent](https://i.am.charlike.online). Released under the [MIT License](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.4.3, on March 09, 2017._  
_Project scaffolded using [charlike][] cli._

[always-done]: https://github.com/hybridables/always-done
[async-done]: https://github.com/gulpjs/async-done
[base]: https://github.com/node-base/base
[charlike]: https://github.com/tunnckocore/charlike
[commitizen]: https://github.com/commitizen/cz-cli
[dezalgo]: https://github.com/npm/dezalgo
[once]: https://github.com/isaacs/once
[standard-version]: https://github.com/conventional-changelog/standard-version
[verb-generate-readme]: https://github.com/verbose/verb-generate-readme
[verb]: https://github.com/verbose/verb

[license-url]: https://www.npmjs.com/package/stack-utils-node-internals
[license-img]: https://img.shields.io/npm/l/stack-utils-node-internals.svg

[downloads-url]: https://www.npmjs.com/package/stack-utils-node-internals
[downloads-img]: https://img.shields.io/npm/dt/stack-utils-node-internals.svg

[codeclimate-url]: https://codeclimate.com/github/tunnckoCore/stack-utils-node-internals
[codeclimate-img]: https://img.shields.io/codeclimate/github/tunnckoCore/stack-utils-node-internals.svg

[travis-url]: https://travis-ci.org/tunnckoCore/stack-utils-node-internals
[travis-img]: https://img.shields.io/travis/tunnckoCore/stack-utils-node-internals/master.svg?label=linux

[appveyor-url]: https://ci.appveyor.com/project/tunnckoCore/stack-utils-node-internals
[appveyor-img]: https://img.shields.io/appveyor/ci/tunnckoCore/stack-utils-node-internals/master.svg?label=windows

[coverage-url]: https://codecov.io/gh/tunnckoCore/stack-utils-node-internals
[coverage-img]: https://img.shields.io/codecov/c/github/tunnckoCore/stack-utils-node-internals/master.svg

[david-url]: https://david-dm.org/tunnckoCore/stack-utils-node-internals
[david-img]: https://img.shields.io/david/tunnckoCore/stack-utils-node-internals.svg

[standard-url]: https://github.com/feross/standard
[standard-img]: https://img.shields.io/badge/code%20style-standard-brightgreen.svg

[paypalme-url]: https://www.paypal.me/tunnckoCore
[paypalme-img]: https://img.shields.io/badge/paypal-donate-brightgreen.svg

[clean-stack]: https://github.com/sindresorhus/clean-stack